# Release History

## 1.0.5 (08/17/2022)

- Improvements around tests and code coverage

## 1.0.4 (08/08/2022)

- Official Documentation site

## 1.0.3 (08/05/2022)

- Standardized documentation

## 1.0.2 (08/02/2022)

- README.md bug fix - diagram not loading properly

## 1.0.1 (08/02/2022)

- Enhanced documentation - logging considerations, ideal scenarios and architectures, contributors guide.

- Unit tests

## 1.0.0 (08/02/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Custom formatting for Python logging, specifically for use on IoT Edge Device modules that intend to send these logs to an Azure Log Analytics workspace
